/*
 * file StpPartialResultsException.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.StpPartialResultsException
 *
 *  Copyright IBM Corporation 2007, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp;

import javax.wvcm.Resource;
import javax.wvcm.ResourceList;
import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

/**
 * An exception used to convey information about an operation that failed on
 * some, but not necessarily all, resources processed by the operation.
 */
public abstract class StpPartialResultsException extends StpPropertyException
{
    /**
     * Returns the list of resources on which the operation succeeded.
     *
     * @return A ResourceList containing a proxy for each resource on which
     * the operation succeeded. Any requested properties will be defined by
     * these proxies.
     */
    public ResourceList<Resource> resourceList()
    {
        return ((PartialResultsData)data()).resourceList();
    }

    /**
     * Returns whether or not the ResourceList of successful resources and the 
     * list of nested exceptions account for all the resources
     * that were supposed to be operated on. If this field is <b>true</b>,
     * there may be resources on which the operation was not performed and hence
     * are neither reported as succeeding or as failing; the failure mode of the 
     * operation was such that the remaining operands could not be processed. 
     *
     * @return <b>true</b> if all the potential operands could not be enumerated;
     * <b>false</b> if all the operands could be enumerated but the operation
     * failed on at least one of them.
     */
    public boolean enumerationError()
    {
        return ((PartialResultsData)data()).enumerationError();
    }

    /**
     * Constructs this exception object for its subclasses.
     * 
     * @param resource The Resource argument to WvcmException
     * @param reasonCode The ReasonCode argument to WvcmException
     * @param nestedExceptions The Throwable[] argument to WvcmException
     * 
     * @see javax.wvcm.WvcmException
     */
    protected StpPartialResultsException(Resource resource,
                                      ReasonCode reasonCode,
                                      Throwable[] nestedExceptions)
    {
        super(resource, reasonCode, nestedExceptions);
    }

    /** 
     * The interface for the data implementation object for this type of 
     * exception
     */
    public interface PartialResultsData extends PropertyData {
        public boolean enumerationError();
        public ResourceList<Resource> resourceList();
    }
}
